@@ -31,8 +31,7 @@ import msal
 import requests
 from azure.storage.blob import ContainerClient
 from pydantic import BaseModel, Field
-from tenacity import Future as tenacity_future
-from tenacity import Retrying, retry
+from tenacity import RetryCallState, retry
 from tenacity.retry import retry_if_exception_type
 from tenacity.stop import stop_after_attempt
 from tenacity.wait import wait_random
@@ -44,6 +43,8 @@ _ACCESSTOKENCACHE_UMASK = 0o077
 ONEFUZZ_BASE_PATH = os.path.join("~", ".cache", "onefuzz")
 DEFAULT_CONFIG_PATH = os.path.join(ONEFUZZ_BASE_PATH, "config.json")
 DEFAULT_TOKEN_PATH = os.path.join(ONEFUZZ_BASE_PATH, "access_token.json")
+REQUEST_CONNECT_TIMEOUT = 30.0
+REQUEST_READ_TIMEOUT = 120.0
 
 LOGGER = logging.getLogger("nsv-backend")
 
@@ -253,7 +254,7 @@ class Backend:
                     headers=headers,
                     json=json_data,
                     params=params,
-                    timeout=(30.0, 30.0),
+                    timeout=(REQUEST_CONNECT_TIMEOUT, REQUEST_READ_TIMEOUT),
                 )
 
                 if response.status_code not in retry_codes:
@@ -281,12 +282,12 @@ class Backend:
         return response.json()
 
 
-def before_sleep(
-    retry_object: Retrying, sleep: float, last_result: tenacity_future
-) -> None:
-    name = retry_object.fn.__name__ if retry_object.fn else "blob function"
+def before_sleep(retry_state: RetryCallState) -> None:
+    name = retry_state.fn.__name__ if retry_state.fn else "blob function"
 
-    why = getattr(last_result, "_exception")
+    why: Optional[BaseException] = None
+    if retry_state.outcome is not None:
+        why = retry_state.outcome.exception()
     if why:
         LOGGER.warning("%s failed with %s, retrying ...", name, repr(why))
     else:
